import { NativeEventEmitter, NativeModules, Platform } from "react-native";

const _RNAudioDevice = NativeModules.RNAudioDevice;
const DeviceInfoEventEmitter = new NativeEventEmitter(_RNAudioDevice);
const _subscriptions = new Map();

class RNAudioDevice {
  constructor() {}

  addEventListener(eventName: string, handler: any) {
    const listener = DeviceInfoEventEmitter.addListener(
      eventName,
      (appStateData) => {
        handler({
          data: appStateData,
        });
      }
    );

    _subscriptions.set(handler, listener);
  }

  /**
   * Removes the listener for network status changes.
   */
  removeEventListener(eventName: string, handler: any) {
    const listener = _subscriptions.get(handler);
    if (!listener) {
      return;
    }
    listener.remove();
    _subscriptions.delete(handler);
  }

  // Start device management thread
  start() {
    _RNAudioDevice.start();
  }

  // Stop device management thread
  stop() {
    _RNAudioDevice.stop();
  }

  // StartRecognize for audio.
  startRecognize(language: string) {
    if (Platform.OS === "android") {
      _RNAudioDevice.startRecognize(language);
    } else {
      _RNAudioDevice.startRecognize();
    }
  }

  // StopRecognize for audio.
  stopRecognize() {
    _RNAudioDevice.stopRecognize();
  }
}

export default new RNAudioDevice();
